# Package to upload files to the Robin Radar API

- new version notifcation -> force user to update

- check version of package API and compare to version of package installed on user's machine

- if version of package API is greater than version of package installed on user's machine, then force user to update

- if version of package API is less than or equal to version of package installed on user's machine, then continue
